"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.pipe = exports.joinPathSegments = void 0;
/**
 * Join the given path segments.
 *
 * - always with a leading slash
 * - never with a trailing slash
 * - no slash before `?` (except for `/?...`)
 */
exports.joinPathSegments = function () {
    var segments = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        segments[_i] = arguments[_i];
    }
    var joined = segments.map(trimSlashes).join('/').replace('/?', '?');
    return joined.startsWith('/') ? joined : "/" + joined;
};
var trimLeadingSlash = function (s) { return (s.startsWith('/') ? s.slice(1) : s); };
var trimTrailingSlash = function (s) { return (s.endsWith('/') ? s.slice(0, -1) : s); };
var trimSlashes = pipe(trimLeadingSlash, trimTrailingSlash);
function pipe() {
    var functions = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        functions[_i] = arguments[_i];
    }
    return function (data) { return functions.reduce(function (value, func) { return func(value); }, data); };
}
exports.pipe = pipe;
